#!/bin/sh
#
# by Chih-Wei Huang
# modified by Pablo Saratxaga <pablo@mandrakesoft.com>
#
#              Updated   22-24 July - 24 August 1999
#        Last modified   8 December 1999
#

#PATH="/bin:/usr/bin:/usr/X11R6/bin:/usr/local/bin"
SCRIPTNAME=`basename $0`

RXVT=/usr/X11R6/bin/rxvt.bin

if [ "$SCRIPTNAME" = "rxvt" -o "$SCRIPTNAME" = "rxvt.sh" ]; then
    if [ ! -z $LC_ALL ]; then
        locale=$LC_ALL
    elif [ ! -z $LC_CTYPE ]; then
        locale=$LC_CTYPE
    elif [ ! -z $LANG ]; then
        locale=$LANG
    fi

    case $locale in
        zh_TW.Big5)
        SCRIPTNAME=crxvt
        ;;

        zh_CN.GB2312)
        SCRIPTNAME=gbrxvt_GB2312
	;;

        zh_CN.gb2312)
        SCRIPTNAME=gbrxvt_gb2312
	;;

        zh_CN)
        SCRIPTNAME=gbrxvt
        ;;

	ja*)
	SCRIPTNAME=jrxvt
	;;

	ko*)
	SCRIPTNAME=krxvt
	;;

      # unknown locale, ignore it
        *)
        FGCOLOR=lightgray
	BGCOLOR=black
	MENU=""
        ;;
    esac

    unset locale
fi

case $SCRIPTNAME in
    crxvt)
    LANG=zh_TW.Big5
    ENC=big5
    XA_FACE=fixed
    XA_FAMILY=default
    XIM=xcin
    MENU="/etc/rxvt/rxvt-zh;big5"
    XMODIFIERS="@im=xcin"
    ;;

    gbrxvt)
    LANG=zh_CN
    ENC=gb
    XA_FACE=fixed
    XA_FAMILY=default
    XIM=xcin-zh_CN
    MENU="/etc/rxvt/rxvt-zh;gb"
    XMODIFIERS="@im=xcin-zh_CN"
    ;;

    gbrxvt_GB2312)
    LANG=zh_CN.GB2312
    ENC=gb
    XA_FACE=fixed
    XA_FAMILY=default
    XIM=xcin-zh_CN.GB2312
    MENU="/etc/rxvt/rxvt-zh;gb"
    XMODIFIERS="@im=xcin-zh_CN.GB2312"
    ;;

    gbrxvt_gb2312)
    LANG=zh_CN.gb2312
    ENC=gb
    XA_FACE=fixed
    XA_FAMILY=default
    XIM=xcin-zh_CN.gb2312
    MENU="/etc/rxvt/rxvt-zh;gb"
    XMODIFIERS="@im=xcin-zh_CN.gb2312"
    ;;

    jrxvt)
    LANG=ja
    ENC=eucj
    XA_FACE=fixed
    XA_FAMILY=default
    XIM=kinput2
    #MENU="/etc/rxvt/rxvt-ja;eucj"
    XMODIFIERS="@im=kinput2"
    ;;

    krxvt)
    LANG=ko
    ENC=kr
    XA_FACE=fixed
    XA_FAMILY=default
    XIM=Ami
    #MENU="/etc/rxvt/rxvt-ko;kr"
    XMODIFIERS="@im=Ami"
    ;;
	
esac

export LANG XMODIFIERS

FGCOLOR=lightgray
BGCOLOR=black
TITLE="CJK RXVT ($LANG)"

ARGS=""

while [ -n "$1" ]; do
    case $1 in
        -km) shift
        ENC=$1
        ;;

        -im) shift
        XIM=$1
        ;;

        -fg) shift
        FGCOLOR=$1
        ;;

        -bg) shift
        BGCOLOR=$1
        ;;

        -T|-title) shift
        TITLE=$1
        ;;

        -menu) shift
        MENU=$1
        ;;

        -nomenu)
        MENU=""
        ;;

        *)
        ARGS="$ARGS $1"
        ;;
    esac
    shift
done

# for display Chinese menu only
# if you didn't need Chinese menu, comment out it
if [ -n "$MENU" ]; then
   #LD_PRELOAD=/usr/share/chinese/xa+cv/wrap.so
   XA_MODE=0
   XA_CVMODE=a
   export LD_PRELOAD XA_MODE XA_CVMODE XA_FACE XA_FAMILY
fi

[ -n "$BGCOLOR" ] && ARGS="-bg $BGCOLOR $ARGS"
[ -n "$FGCOLOR" ] && ARGS="-fg $FGCOLOR $ARGS"
[ -n "$XIM" ] && ARGS="-im $XIM $ARGS"
[ -n "$ENC" ] && ARGS="-km $ENC $ARGS"

exec $RXVT -T "$TITLE" -menu "$MENU" $ARGS

